@@ -60,7 +60,7 @@ int main(int argc, char* argv[])
     app.setApplicationVersion(QLatin1String(KIPI_VERSION_STRING));
     app.setOrganizationName(QLatin1String("http://www.digikam.org"));
     app.setWindowIcon(QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                                   QLatin1String("kf5/kipi/pics/kipi-icon.svg"))));
+                                                   QLatin1String(":/images/kipi-icon.svg"))));
 
     QCommandLineParser parser;
     parser.addVersionOption();
